import sys
from . import password, sha512, sha256, randint, uuid, salt
from .constants import VERSION

def main():
    if len(sys.argv) < 2:
        print(f"--- Secretting {VERSION} CLI ---")
        print("Usage:")
        print("python -m secretting pass [len] - Generate secure password")
        print("python -m secretting sha256 [text] - Hashes text to SHA256")
        print("python -m secretting sha512 [text] - Hashes text to SHA512")
        print("python -m secretting random [min] [max] - Generates random number")
        print("python -m secretting uuid - Generates random UUID")
        print("python -m secretting salt [len] - Generates random salt")
        print("python -m secretting data - View all data of secretting")
        return

    cmd = sys.argv[1].lower()

    if cmd == "pass":
        length = int(sys.argv[2]) if len(sys.argv) > 2 else 12
        print(f"Generated password: {password(length)}")
    elif cmd == "sha256":
        text = " ".join(sys.argv[2:])
        print(f"Hashed to SHA256: {sha256(text)}")
    elif cmd == 'sha512':
        text = " ".join(sys.argv[2:])
        print(f"Hashed to SHA512: {sha512(text)}")
    elif cmd == 'random':
        min = sys.argv[2]
        max = sys.argv[3]
        print(f'Random number from {min} to {max}: {randint(int(min), int(max))}')
    elif cmd == 'uuid':
        print(f"UUID: {uuid()}")
    elif cmd == 'salt':
        length = int(sys.argv[2]) if len(sys.argv) > 2 else 12
        print(f"Generated salt: {salt(length)}")
    elif cmd == 'data':
        print(f"""Name: Secretting
Version: {VERSION}
Author: kanderusss
Author email: kanderusss.dev@gmail.com
Url: https://pypi.org/project/secretting/""")
    else:
        print(f'Unknown command: "{cmd}"')

if __name__ == "__main__":
    try:
        main()
    except Exception as e:
        print(f'Error: {e.__class__.__name__}: {e}')



class SecrettingError(Exception):
    """Secretting error. Yeah."""
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
class ChaosEngineError(Exception):
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
class AccessDeniedError(Exception):
    def __init__(self, msg, *args, **kwds):
        super().__init__(msg, *args, **kwds)
        



from string import ascii_letters as letters, digits, punctuation

DEFAULT_CHARS: tuple = (*letters, *digits, *punctuation)
DEFAULT_RATINGS = {
        "0 1": "easy",
        "2 5": "normal",
        "6 8": "hard",
        "9 15": "insane",
        "16 25": "extreme",
        "25 90": "impossible"
}

DEFAULT_BLACKLIST = [
        "123456", "12345678", "password", "qwerty", "admin", "12345",
        '55555', '88888888', '0000', '999999999'
]
AUTHOR = 'kanderusss'
VERSION = '1.18.1'



from setuptools import setup, find_packages

version = '1.18.1'

desc = 'Stealthy text steganography and high-entropy secret generation.'

setup(
    name='secretting',
    version=version,
    description=desc,
    author_email="kanderusss.dev@gmail.com",
    url="https://pypi.org/project/secretting/",
    project_urls={
        "Documentation": "https://pypi.org/project/secretting/",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Security :: Cryptography'
    ],
    python_requires='>=3.6',
    author='kanderusss',
    long_description=f'''# Secretting {version}

# {desc}
# Installation:
```bash
pip install secretting=={version}
```
## If wont work:
```bash
pip3 install secretting=={version}
```

# Example:
```python
from secretting import *

salt() # Output: salt
sha256("a") # Output: hash
secure256("a") # Output: (hash, salt)
isEqual(1, 1) # Output: True
isEqual(1, 2) # Output: False
chars # Output: (ascii_letters, digits, punctuation)
tokenHex(32) # Output: token with 32 bytes

# And more nice tools!
```
# Libs:
## Secrets (choice, compare_digest)
## Random (shuffle, random, randint)
## String (ascii_letters, digits, punctuation)
## Hashlib (sha256, sha512)
## GetPass (getpass)
## Typing (any)

# Github
## [My github account](https://www.youtube.com/watch?v=dQw4w9WgXcQ)

# Random scheme
## Secretting uses Chaos 20 system
## How it works:
```python
import secrets

def x_or_o():
    return secrets.choice(["x", "o"])
def chaos20system(func, *args, **kwargs):
    return secrets.choice([func(*args, **kwargs) for _ in range(20)])
# This is list of 20 functions runs.
# Chaos 20 System returns 1 random of this list.
# It is more random than secrets.choice and random.choice.
# Secretting made by this scheme only.
# And yeah its made by me.
# You can copy this scheme.
```

# Changelog

# [{version}]


## Removed
- **All functions that wasn't working was removed.**


# Enjoy it!

![PyPI - Version](https://img.shields.io/pypi/v/secretting)
![PyPI - Downloads](https://img.shields.io/pypi/dm/secretting)
![PyPI - License](https://img.shields.io/pypi/l/secretting)
![PyPi - Badge](https://img.shields.io/pypi/v/secretting?color=green&logo=python)
![PyPi - Status](https://img.shields.io/pypi/status/secretting)
![PyPi - Format](https://img.shields.io/pypi/format/secretting)
![PyPi - PyVersions](https://img.shields.io/pypi/pyversions/secretting)
''',
    long_description_content_type='text/markdown',
    install_requires=[],
    packages=find_packages(),
    license='MIT'
)
